@@ -1,9 +1,19 @@
-#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+# BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
+# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# 
+# A significant portion of this module originates from:
+# Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+# Copyright (C) 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+# 
+# This module is under a dual license:
+# 1. The UIUC open-source license. See 
+# github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
+# for license details.
+# 
+# 2. The MIT open-source license. See
+# https://github.com/CalebBell/thermo/blob/master/LICENSE.txt for details.
 """
-Created on Mon Apr 16 08:58:41 2018
-
-@author: Yoel Rene Cortes-Pena
 """
 import numpy as np
 from ..properties.unifac import DOUFSG, DOUFIP2016, UFIP, UFSG
@@ -92,6 +102,7 @@ def psi_Dortmund(T, abc):
 def psi_UNIFAC(T, a):
     return np.exp(-a/T)
 
+
 # %% Activity Coefficients
 
 class ActivityCoefficients:
