@@ -13,6 +13,7 @@ from .solve_vle_composition import solve_y
 from ..functional import normalize
 from ..utils import fill_like, Cache
 from .._settings import settings
+from .activity_coefficients import IdealActivityCoefficients
 
 __all__ = ('BubblePoint', 'BubblePointValues', 'BubblePointCache')
 
@@ -54,10 +55,10 @@ class BubblePoint:
     >>> # Solve bubble point at constant temperature
     >>> bp = BP(z=molar_composition, T=355)
     >>> bp
-    BubblePointValues(T=355, P=109755.45319869411, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.343 0.657])
+    BubblePointValues(T=355, P=109755.45319869413, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.343 0.657])
     >>> # Note that the result is a BubblePointValues object which contain all results as attibutes
     >>> (bp.T, bp.P, bp.IDs, bp.z, bp.y)
-    (355, 109755.45319869411, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.343, 0.657]))
+    (355, 109755.45319869413, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.343, 0.657]))
     >>> # Solve bubble point at constant pressure
     >>> BP(z=molar_composition, P=101325)
     BubblePointValues(T=352.95030269946596, P=101325, IDs=('Water', 'Ethanol'), z=[0.5 0.5], y=[0.342 0.658])
@@ -86,6 +87,7 @@ class BubblePoint:
             cached[key] = self
     
     def _T_error(self, T, P, z_over_P, z_norm,):
+        if T <= 0: raise flx.InfeasibleRegion('negative temperature')
         y_phi =  (z_over_P
                   * array([i(T) for i in self.Psats])
                   * self.gamma(z_norm, T) 
@@ -94,6 +96,7 @@ class BubblePoint:
         return 1. - self.y.sum()
     
     def _P_error(self, P, T, z_Psat_gamma_pcf):
+        if P <= 0: raise flx.InfeasibleRegion('negative temperature')
         y_phi = z_Psat_gamma_pcf / P
         self.y = solve_y(y_phi, self.phi, T, P, self.y)
         return 1. - self.y.sum()
@@ -151,10 +154,20 @@ class BubblePoint:
             f = lambda T: self._T_error(T, *args)
             Tmin = max([i.Tmin for i in self.Psats]) + 1e-5
             Tmax = min([i.Tmax for i in self.Psats]) - 1e-5
-            if Tmin < 10: Tmin = 10
+            if Tmin < 50: Tmin = 50
             self.T = flx.IQ_interpolation(f, Tmin, Tmax,
                                           f(Tmin), f(Tmax),
                                           T, 0., 1e-6, 5e-9)
+            if Tmin < 51:
+                # Couldn't solve; so ignore activity coefficients
+                gamma_old = self.gamma
+                self.gamma = IdealActivityCoefficients(gamma_old.chemicals)
+                try:
+                    self.T = flx.IQ_interpolation(f, Tmin, Tmax,
+                                                  f(Tmin), f(Tmax),
+                                                  T, 0., 1e-6, 5e-9)
+                finally: self.gamma = gamma_old
+                
         self.y = normalize(self.y)
         return self.T, self.y.copy()
     
@@ -184,7 +197,7 @@ class BubblePoint:
         >>> tmo.settings.set_thermo(chemicals)
         >>> BP = tmo.equilibrium.BubblePoint(chemicals)
         >>> BP.solve_Py(z=np.array([0.703, 0.297]), T=352.28)
-        (91830.97988957874, array([0.419, 0.581]))
+        (91830.9798895787, array([0.419, 0.581]))
         
         """
         Psats = array([i(T) for i in self.Psats])
@@ -197,7 +210,7 @@ class BubblePoint:
             self.P = flx.aitken_secant(self._P_error, P, P-1,
                                        1e-3, 1e-9, args)
         except:
-            self.x = z.copy()
+            self.y = z.copy()
             P = (z * Psats).sum()
             Pmin = min([i(i.Tmin + 1e-5 if i.Tmin > 10 else 10) for i in self.Psats])
             Pmax = max([i(i.Tmax - 1e-5) for i in self.Psats])
