@@ -54,10 +54,10 @@ class DewPoint:
     >>> molar_composition = (0.5, 0.5)
     >>> dp = DP(z=molar_composition, T=355)
     >>> dp
-    DewPointValues(T=355, P=91970.14968399647, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.851 0.149])
+    DewPointValues(T=355, P=91970.14968399628, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.851 0.149])
     >>> # Note that the result is a DewPointValues object which contain all results as attibutes
     >>> (dp.T, dp.P, dp.IDs, dp.z, dp.x)
-    (355, 91970.14968399647, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.851, 0.149]))
+    (355, 91970.14968399628, ('Water', 'Ethanol'), array([0.5, 0.5]), array([0.851, 0.149]))
     >>> # Solve for dew point at constant pressure
     >>> DP(z=molar_composition, P=2*101324)
     DewPointValues(T=376.2616600249248, P=202648, IDs=('Water', 'Ethanol'), z=[0.5 0.5], x=[0.832 0.168])
@@ -86,7 +86,7 @@ class DewPoint:
             cached[key] = self
     
     def _T_error(self, T, P, z_norm, zP):
-        if T < 0: raise flx.InfeasibleRegion('negative pressure')
+        if T < 0: raise flx.InfeasibleRegion('negative temperature')
         Psats = [i(T) for i in self.Psats]
         # Remove small values to prevent floating point error
         Psats = array([i if i > 1e-16 else 1e-16 for i in Psats])
@@ -138,7 +138,7 @@ class DewPoint:
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
         >>> DP.solve_Tx(z=np.array([0.5, 0.5]), P=101325)
-        (357.4518474332522, array([0.849, 0.151]))
+        (357.4518474332535, array([0.849, 0.151]))
         
         """
         z_norm = z/z.sum()
@@ -186,7 +186,7 @@ class DewPoint:
         >>> tmo.settings.set_thermo(chemicals)
         >>> DP = tmo.equilibrium.DewPoint(chemicals)
         >>> DP.solve_Px(z=np.array([0.5, 0.5]), T=352.28)
-        (82444.29876047903, array([0.853, 0.147]))
+        (82444.29876047901, array([0.853, 0.147]))
  
        """
         z_norm = z/z.sum()
