@@ -34,6 +34,9 @@ class DimensionError(ValueError):
 
 class DomainError(ValueError):
     """ValueError regarding an attempt to evaluate a model out of its domain."""
+    def __init__(self, msg, **data):
+        super().__init__(self, msg)
+        self.__dict__.update(data)
 
 class InvalidMethod(ValueError):
     """ValueError regarding an attempt to evaluate an invalid method."""
@@ -48,8 +51,10 @@ def message_with_object_stamp(object, msg):
         return colors.violet(object_name) + ' ' + msg
 
 def raise_error_with_object_stamp(object, error):
-    msg, *args = error.args
-    error.args = (message_with_object_stamp(object, msg), *args)
+    try: 
+        msg, *args = error.args
+        error.args = (message_with_object_stamp(object, msg), *args)
+    except: pass
     raise error
 
 def try_method_with_object_stamp(object, method, args=()):
