@@ -1,4 +1,18 @@
 # -*- coding: utf-8 -*-
+# BioSTEAM: The Biorefinery Simulation and Techno-Economic Analysis Modules
+# Copyright (C) 2020, Yoel Cortes-Pena <yoelcortes@gmail.com>
+# 
+# A significant portion of this module originates from:
+# Chemical Engineering Design Library (ChEDL). Utilities for process modeling.
+# Copyright (C) 2020 Caleb Bell <Caleb.Andrew.Bell@gmail.com>
+# 
+# This module is under a dual license:
+# 1. The UIUC open-source license. See 
+# github.com/BioSTEAMDevelopmentGroup/biosteam/blob/master/LICENSE.txt
+# for license details.
+# 
+# 2. The MIT open-source license. See
+# https://github.com/CalebBell/thermo/blob/master/LICENSE.txt for details.
 """
 All data and methods related to the vapor pressure of a chemical.
 
@@ -525,7 +539,7 @@ def vapor_pressure_handle(handle, CAS, Tb, Tc, Pc, omega):
         add_model(Wagner_McGraw.from_args(data), Tmin, Tmax)
     if CAS in Psat_data_AntoineExtended:
         _, a, b, c, Tc, to, n, e, f, Tmin, Tmax = Psat_data_AntoineExtended[CAS]
-        data = (a, b, c, Tc, to, n, e, f)
+        data = (Tc, to, a, b, c, n, e, f)
         add_model(TRC_Extended_Antoine.from_args(data), Tmin, Tmax)
     if CAS in Psat_data_Antoine:
         _, a, b, c, Tmin, Tmax = Psat_data_Antoine[CAS]
